@@ -6,6 +6,15 @@ const completion: Fig.Spec = {
       name: "add",
       description: "Add a new directory or increment its rank",
       options: [
+        {
+          name: ["-s", "--score"],
+          description: "The rank to increment the entry if it exists or initialize it with if it doesn't",
+          isRepeatable: true,
+          args: {
+            name: "score",
+            isOptional: true,
+          },
+        },
         {
           name: ["-h", "--help"],
           description: "Print help",
@@ -182,10 +191,10 @@ const completion: Fig.Spec = {
           "bash",
           "elvish",
           "fish",
-          "ksh",
           "nushell",
           "posix",
           "powershell",
+          "tcsh",
           "xonsh",
           "zsh",
         ],
@@ -205,6 +214,16 @@ const completion: Fig.Spec = {
             template: "folders",
           },
         },
+        {
+          name: "--base-dir",
+          description: "Only search within this directory",
+          isRepeatable: true,
+          args: {
+            name: "base_dir",
+            isOptional: true,
+            template: "folders",
+          },
+        },
         {
           name: ["-a", "--all"],
           description: "Show unavailable directories",
